@@ -11,7 +11,7 @@ import deskbar.interfaces.Action
 import deskbar.interfaces.Match
 import deskbar.interfaces.Module
 import glob
-import gobject
+import glib
 import gtk
 import os
 import re
@@ -228,8 +228,8 @@ class OpenPathProgramAction(deskbar.interfaces.Action):
                     stdin=prog.stdout)
     
                 # Reap the processes when they have done
-                gobject.child_watch_add(zenity.pid, lambda pid, code: None)
-                gobject.child_watch_add(prog.pid, lambda pid, code: None)
+                glib.child_watch_add(zenity.pid, lambda pid, code: None)
+                glib.child_watch_add(prog.pid, lambda pid, code: None)
                 return
             except:
                 #No zenity, get out of the if, and launch without GUI
@@ -309,13 +309,14 @@ class ProgramsHandler(deskbar.interfaces.Module):
         if len(args) == 1:
             results = []
             for pathdir in PATH:
-                for f in os.listdir(pathdir):
-                    pathprog = join(pathdir, f)
-                    if (not (f in desktop_progs)) and not isdir(pathprog) \
-                    and f.lower().startswith(program) and is_executable(pathprog):
-                        match = StartsWithPathProgramMatch(f)
-                        match.set_priority (self.get_priority() + get_priority_for_name(query, f))
-                        results.append( match )
+                if isdir(pathdir) and is_executable(pathdir):
+                    for f in os.listdir(pathdir):
+                        pathprog = join(pathdir, f)
+                        if (not (f in desktop_progs)) and not isdir(pathprog) \
+                        and f.lower().startswith(program) and is_executable(pathprog):
+                            match = StartsWithPathProgramMatch(f)
+                            match.set_priority (self.get_priority() + get_priority_for_name(query, f))
+                            results.append( match )
             return results
         else:
             # We have arguments, execute the command as typed in by the user
