@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
-from gettext import gettext as _
+from deskbar.core.Utils import launch_default_for_uri
 from deskbar.defs import VERSION
-import gtk, gtk.gdk, gnomevfs
+from gettext import gettext as _
+import gtk
+import gtk.gdk
 
 
 def on_email(about, mail):
-    gnomevfs.url_show("mailto:%s" % mail)
+    launch_default_for_uri("mailto:%s" % mail)
 
 def on_url(about, link):
-    gnomevfs.url_show(link)
+    launch_default_for_uri(link)
 
 gtk.about_dialog_set_email_hook(on_email)
 gtk.about_dialog_set_url_hook(on_url)
@@ -16,21 +18,19 @@ gtk.about_dialog_set_url_hook(on_url)
 def show_about(parent):
     about = gtk.AboutDialog()
     infos = {
-        "name" : _("Deskbar"),
-        "logo-icon-name" : "deskbar-applet",
-        "version" : VERSION,
+        "authors": ["Nigel Tao <nigel.tao@myrealbox.com>",
+                    "Raphael Slinckx <raphael@slinckx.net>",
+                    "Mikkel Kamstrup Erlandsen <kamstrup@daimi.au.dk>",
+                    "Sebastian Pölsterl <marduk@k-d-w.org>"],
         "comments" : _("An all-in-one action bar."),
-        "copyright" : "Copyright © 2004-2006\nNigel Tao, Raphael Slinckx, Mikkel Kamstrup Erlandsen, Sebastian Pölsterl.",
-        "website" : "http://raphael.slinckx.net/deskbar",
-        "website-label" : _("Deskbar Website"),
+        "copyright" : "Copyright © 2004-2008\nNigel Tao, Raphael Slinckx, Mikkel Kamstrup Erlandsen, Sebastian Pölsterl.",
+        "documenters" : ["Phil Bull <philbull@gmail.com>", "Qing Gan"],
+        "logo-icon-name" : "deskbar-applet",
+        "name" : _("Deskbar"),
+        "version" : VERSION,
+        "website" : "http://www.gnome.org/projects/deskbar-applet/",
+        "website-label" : _("Deskbar Website"),   
     }
-
-    about.set_authors(["Nigel Tao <nigel.tao@myrealbox.com>",
-                       "Raphael Slinckx <raphael@slinckx.net>",
-                       "Mikkel Kamstrup Erlandsen <kamstrup@daimi.au.dk>",
-                       "Sebastian Pölsterl <marduk@k-d-w.org>"])
-#    about.set_artists([])
-#    about.set_documenters([])
     
     #translators: These appear in the About dialog, usual format applies.
     about.set_translator_credits( _("translator-credits") )
